For the detailed tutorial on microeco package, please follow the links:
Online tutorial website: https://chiliubio.github.io/microeco_tutorial/
Download tutorial: https://github.com/ChiLiubio/microeco_tutorial/releases
For each R6 class, please open the help document by searching the class name.
For example, to search microtable class, please run the command help(microtable) or ?microtable.
Another way to open the help document of R6 class is to click the following links collected:
microtable
trans_abund
trans_venn
trans_alpha
trans_beta
trans_diff
trans_network
trans_nullmodel
trans_classifier
trans_env
trans_func
trans_norm
To report bugs or discuss questions, please use Github Issues (https://github.com/ChiLiubio/microeco/issues). Before creating a new issue, please read the guideline (https://chiliubio.github.io/microeco_tutorial/notes.html#github-issues).
To cite microeco package in publications, please run the following command to get the references: citation("microeco")
Reference:
Chi Liu, Felipe R. P. Mansoldo, Hankang Li, Alane Beatriz Vermelho, Raymond Jianxiong Zeng, Xiangzhen Li & Minjie Yao.
A workflow for statistical analysis and visualization of microbiome omics data using the R microeco package.
Nature Protocols (2025). DOI:10.1038/s41596-025-01239-4
Chi Liu, Yaoming Cui, Xiangzhen Li & Minjie Yao. microeco: an R package for data mining in microbial community ecology. FEMS Microbiology Ecology, 2021, 97(2): fiaa255. DOI:10.1093/femsec/fiaa255