Learn R Programming

microeco (version 2.3.0)

soil_metab: Microtable object of non-targeted metabolome data from bulk soil and maize rhizosphere soil in an agricultural field experiment with crop rotation and fertilization treatments (DOI: 10.1007/s11104-024-06847-9).

Description

For the explanation of each column of sample_table, please refer to the soil_microb data document. In tax_table, 'HMDB_ID' is the number of HMDB database. 'KEGG_ID' is the number of KEGG database.

  • sample_table: sample information table

  • otu_table: metabolites abundance table

  • tax_table: annotation table

Usage

data(soil_metab)

Arguments

Format

R6 class object