Learn R Programming

microeco (version 2.3.0)

soil_microb: Microtable object of prokaryotic sequencing data from soil and maize in an agricultural field experiment with crop rotation and fertilization treatments (DOI: 10.1007/s11104-024-06847-9).

Description

In the first column of sample_table, 'SampleID', is the sample name and same with the row names. The second column, 'Group', represents different treatment groups, namely the combinations of 'Cropping' and 'Fertilization', which are two experimental factors. 'Cropping' denotes the experimental treatments including rotational (RC) and continuous (CC) cropping, and 'Fertilization' includes CK (no fertilizer control), NPK (inorganic fertilizer) and NPKS (NPK + straw amendment). 'Compartment' means different sampling compartments (bulk soil, rhizosphere soil and root).

Usage

data(soil_microb)

Arguments

Format

R6 class object

Details

  • sample_table: sample information table

  • otu_table: ASV abundance table

  • tax_table: taxonomic table